// Take a look at the license at the top of the repository in the LICENSE file.

pub use crate::auto::*;

pub use crate::font_map::FontMapExtManual;
#[doc(hidden)]
pub use glib::prelude::*;
#[doc(hidden)]
pub use pango::prelude::*;
